// Copyright 2015-2018 The NATS Authors
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.


#ifndef NATSTIME_H_
#define NATSTIME_H_

#include "natsp.h"

typedef struct __natsDeadline
{
    int64_t             absoluteTime;
    bool                active;

} natsDeadline;

void
natsDeadline_Init(natsDeadline *deadline, int64_t timeout);

int
natsDeadline_GetTimeout(natsDeadline *deadline);

void
natsDeadline_Clear(natsDeadline *deadline);

int64_t
nats_setTargetTime(int64_t timeout);

#endif /* NATSTIME_H_ */
